# Ideas for futur project

## Feature

* Theta profile, profile along the major axis
* Contrast Map, image with constrat as intensity
* Recursive annulus phot

## Interface

* 9: 2h Jupyter kernel, autowrite print(sm)
* 3: 2h Datacube if more than 3 dimension
* 5: 4h UI: Add some colorscheme (material)
